stringtools.is_underscore_delimited_lowercase_string
====================================================

.. autofunction:: abjad.tools.stringtools.is_underscore_delimited_lowercase_string.is_underscore_delimited_lowercase_string
   :noindex:
